<?php
require_once("db/DietDB.class.php");
require_once("error/error.inc.php");

class DBUserConf {
    protected $dbh;
    
    function __construct($dbh = null) {
        if ($dbh == null) {
            $this->dbh = DietDB::getHandler();
        } else {
            $this->dbh = $dbh;
        }
    }

    function get($key) {
        $users_id = empty($_SESSION['user_id']) ? -1: $_SESSION['user_id'];
        if ($users_id <= 0) {
            return null;
        }

        $stmt = $this->dbh->prepare("select val from user_conf ".
                                    "where users_id = ? and key_name = ?;");
        $stmt->execute(array($users_id, $key));
        return $stmt->fetchColumn();
    }

    function getAll() {
        $users_id = empty($_SESSION['user_id']) ? -1: $_SESSION['user_id'];
        if ($users_id <= 0) {
            return array();
        }
        $stmt = $this->dbh->prepare("select key_name, val from user_conf ".
                                    "where users_id = ?;");
        $stmt->execute(array($users_id));
        $conf = array();
        while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
            $key = $row['key_name'];
            $conf[$key] = $row['val'];
        }
        return $conf;
    }

    function set($mob_only = false) {
        $users_id = empty($_SESSION['user_id']) ? -1: $_SESSION['user_id'];
        if ($users_id <= 0) {
            return;
        }
        $gif = (int)$_REQUEST['gif'];
        if (!$mob_only) {
            $width = (int)$this->getWidth();
            $height = (int)$this->getHeight();
        }
        $mob_width = (int)$this->getMobWidth();
        $mob_height = (int)$this->getMobHeight();
    
        $this->doSet("gif", $gif);
        if (!$mob_only) {
            $this->doSet("width", $width);
            $this->doSet("height", $height);
        }
        $this->doSet("mob_width", $mob_width);
        $this->doSet("mob_height", $mob_height);
    }

    protected function doSet($key, $val) {
        $users_id = $_SESSION['user_id'];
        $stmt = $this->dbh->prepare("select users_id from user_conf ".
                                    "where users_id = ? and key_name = ?;");
        $stmt->execute(array($users_id, $key));
        $flag = $stmt->fetchColumn();
        if ($flag) {
            $stmt = $this->dbh->prepare("update user_conf set val = ?, ".
                                        "  up_date = current_timestamp ".
                                        "where users_id = ? and ".
                                        "  key_name = ?;");
            $stmt->execute(array($val, $users_id, $key));

        } else {
            $stmt = $this->dbh->prepare("insert into user_conf(".
                                        "  users_id, key_name, val) ".
                                        "values(?, ?, ?);");
            $stmt->execute(array($users_id, $key, $val));
        }
    }

    protected function getWidth() {
        $width = (int)$_REQUEST['width'];
        if ($width <= 0 || $width > 3000) {
            error_show_width();
            exit;
        }
        return $width;
    }
    protected function getHeight() {
        $height = (int)$_REQUEST['height'];
        if ($height <= 0 || $height > 3000) {
            error_show_height();
            exit;
        }
        return $height;
    }
    protected function getMobWidth() {
        $mob_width = (int)$_REQUEST['mob_width'];
        if ($mob_width <= 0 || $mob_width > 3000) {
            error_show_mob_width();
            exit;
        }
        return $mob_width;
    }
    protected function getMobHeight() {
        $mob_height = (int)$_REQUEST['mob_height'];
        if ($mob_height <= 0 || $mob_height > 3000) {
            error_show_mob_height();
            exit;
        }
        return $mob_height;
    }
}
?>