<?php
require_once("db/DietDB.class.php");
require_once("util/util.inc.php");
require_once("defense/DBDefense.class.php");
require_once("error/error.inc.php");

class DBUsers {
    protected $dbh;

    function __construct($dbh = null) {
        if ($dbh == null) {
            $this->dbh = DietDB::getHandler();
        } else {
            $this->dbh = $dbh;
        }
    }

    function isUniqueUsername($username) {
        $stmt = $this->dbh->prepare("select name from users where name = ?;");
        $stmt->execute(array($username));
        $res = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($res) {
            return false;
        } else {
            return true;
        }
    }

    function add($username, $password) {
        $stmt = $this->dbh->prepare("insert into users(name, password) ".
                             "values(?,?);");
        $stmt->execute(array($username, $password));
    }

    function set() {
        $dbDef = new DBDefense($this->dbh);
        $users_id = $_SESSION['user_id'];
        $public = $_REQUEST['public'] == 1 ? "t" : "f";
        $pub_name = $_REQUEST['pub_name'];
        if (strlen($pub_name) > 100) {
            $dbDef->add(__FILE__.":".__LINE__);
        }
        $short_comment = $_REQUEST['short'];
        if (strlen($short_comment) > 150) {
            $dbDef->add(__FILE__.":".__LINE__);
        }
        $long_comment = $_REQUEST['long'];
        if (strlen($long_comment) > 1000) {
            $dbDef->add(__FILE__.":".__LINE__);
        }
        $stmt = $this->dbh->prepare("update users set public = ?, ".
                                    "  pub_name = ?, ".
                                    "  short_comment = ?, long_comment = ?, ".
                                    "  up_date = current_timestamp ".
                                    "where id = ?;");
        $stmt->execute(array($public, $pub_name, 
                             $short_comment, $long_comment,
                             $users_id));
    }

    function checkPassword($username, $password) {
        $stmt = $this->dbh->prepare("select id from users ".
                                    "where name= ? and password = ?;");
        $stmt->execute(array($username, $password));
        $res = $stmt->fetch(PDO::FETCH_ASSOC);
        if (!$res) {
            return -1;
        }
        return $res['id'];
    }

    function isPublic($users_id) {
        $users_id = util_get_safe($users_id);
        $stmt = $this->dbh->prepare("select id from users " .
                                    "where id = ? and public = 't';");
        $stmt->execute(array($users_id));
        $res = $stmt->fetch(PDO::FETCH_ASSOC);
        if (!$res) {
            return false;
        }
        return true;
    }

    function getPubUsers() {
        $stmt = $this->dbh->prepare("select id, pub_name, short_comment, " .
                                    "  up_date ".
                                    "from users ".
                                    "where public = 't' " .
                                    "order by up_date desc;");
        $stmt->execute();
        $pub_users = $stmt->fetchAll(PDO::FETCH_ASSOC);
        if ($pub_users == null) $pub_users = array();
        return $pub_users;
    }

    static function getNextMessId($dbh, $users_id) {
        $stmt = $dbh->prepare("select cur_mess_id from users where id = ?;");
        $stmt->execute(array($users_id));
        $cur_mess_id = $stmt->fetchColumn();
        $cur_mess_id++;
        $stmt = $dbh->prepare("update users set cur_mess_id = ?, ".
                             "up_date = current_timestamp where id = ?;");

        $stmt->execute(array($cur_mess_id, $users_id));
        return $cur_mess_id;
    }

    function setUpDate($users_id) {
        $stmt = $this->dbh->prepare("update users " .
                                    "set up_date = current_timestamp ".
                                    "where id = ?;");
        $stmt->execute(array($users_id));
    }

    function getByIdForFriend($id_for_friend) {
        $stmt = $this->dbh->prepare("select id from users " .
                                    "where id_for_friend = ?;");
        $stmt->execute(array($id_for_friend));
        return $stmt->fetchColumn();
    }    


}

?>