<?php
require_once("def/def_conf.inc.php");
require_once("def/def_ope.inc.php");
require_once("user/user.inc.php");
require_once("user/User.class.php");
require_once("user/DBUsers.class.php");
require_once("user/DBUserConf.class.php");
require_once("weight/DBWeight.class.php");
require_once("page/page.inc.php");
require_once("ope/DBOperation.class.php");
require_once("defense/DBDefense.class.php");
require_once("error/error.inc.php");
require_once("util/_H.inc.php");

class UserSettingPage extends Page {
    protected $need_auth = true;
    protected $dbh;

    function prepare_update(&$args) {
        $pub_name = trim($_REQUEST['pub_name']);
        if ($_REQUEST['public'] == 1 && empty($pub_name)) {
            $args['error_message'] = "公開する時は、公開用の名前が必要です。";
            return false;
        }
        $dbUsers = new DBUsers($this->dbh);
        $dbUsers->set();
        $args['message'] = "更新しました。";
        return true;
    }

    function prepare(&$args) {
        $args['message'] = "";
        $args['error_message'] = "";

        $mode = empty($_REQUEST['mode']) ? null: $_REQUEST['mode'];
        if ($mode == "update") {
            if ($this->prepare_update($args)) {
                $args['success_update'] = true;
            } else {
                $args['success_update'] = false;
            }
        }
        $users_id = $_SESSION['user_id'];
        $this->dbh = DietDB::getHandler();
        $user = new User($users_id, $this->dbh);
        $user->load();
        $args['public'] = $user->public;
        $args['pub_name'] = $user->pub_name;
        $args['short_comment'] = $user->short_comment;
        $args['long_comment'] = rtrim($user->long_comment);
    }

    function echo_head() {
        Page::echo_head(array("title" => "公開用設定",
                             "refresh" => SESSION_LIFETIME + 120,
                             "style_sheet" =>"css/setting.css"));
    }

    function echo_body(&$args) {
?>
<h1>公開用設定</h1>
<div id="first">
     <?php part_echo_navi("公開用設定"); ?>
</div> <!-- first -->

<div id="second">
  <div id="message">
      <?= _H($args['message']) ?>
  </div>
  <span class="error"><?= _H($args['error_message']) ?></span>
  <form action="<?= TOP_PAGE ?>" method="post">
  <p>
     <input type="radio" name="public" value="1" <?= $args['public'] == 1 ? "checked" : ""  ?>>公開する
     <input type="radio" name="public" value="0" <?= $args['public'] != 1 ? "checked" : "" ?>>非公開にする
  </p>
  <p>
     公開用の名前(必須): 
      <input type="text" name="pub_name" size="20" maxlength="40"
            value="<?= _H($args['pub_name']) ?>">
  </p>
  <p>
     1行アピール：
      <input type="text" name="short" size="30" maxlength="100"
            value="<?= _H($args['short_comment']) ?>">
  </p>
  <p>
     プロフィールなど<br>
      <textarea name="long" cols="40" rows="10"><?= _H($args['long_comment']) ?></textarea>
  </p>
  <p>
     <input type="submit" value="更新">
     <input type="hidden" name="cmd" value="setting">
     <input type="hidden" name="mode" value="update">
  </p>
   </form>
</div> <!-- second -->
<?php
    } //echo_body()

}

class UserEditPage extends Page {
    protected $need_auth = true;
    protected $start;
    protected $end;

    function get_offset($jumpy, $jumpm) {
        if ($jumpy < START_YEAR || $jumpy > date("Y")) {
            error_show_year();
            exit;
        }
        if ($jumpm < 1 || $jumpm > 12) {
            error_show_month();
        }
        $diff = time() - mktime(0, 0, 0, $jumpm, 1, $jumpy);
        return floor($diff / (7* 24* 3600));
    }

    function set_start_and_end(&$args) {
        $next_day = util_next_day(time());
        $y = date("Y", $next_day);
        $m = date("n", $next_day);
        $d = date("j", $next_day);
        $this->start = mktime(0, 0, 0,
                          $m, $d - ($args['offset'] + 1) * 7, $y);
        $this->end = mktime(0, 0, 0, $m, $d - $args['offset'] * 7, $y);
        $a = getdate($this->start);
        $args['start_str'] = $a['year']."年".$a['mon']."月".$a['mday']."日";
        $a = getdate(util_prev_day($this->end));
        $args['end_str'] = $a['year']."年".$a['mon']."月".$a['mday']."日";
    }
        
    function toDB($command, &$args) {
        $dbh = DietDB::getHandler();
        $dbDef = new DBDefense($dbh);
        $dbWeight = new DBWeight($dbh);
     
        if ($command == "update") {
            $dbWeight->setMass();
        } else if ($command == "delete") {
            $dbWeight->delete();
            $args['post_year'] = empty($_REQUEST['year']) ?
                null: (int)$_REQUEST['year'];
            $args['post_month'] = empty($_REQUEST['month']) ?
                null: (int)$_REQUEST['month'];
            $args['post_day'] = empty($_REQUEST['day']) ?
                null: (int)$_REQUEST['day'];
            $args['post_hour'] = empty($_REQUEST['hour']) ?
                null: (int)$_REQUEST['hour'];
            $args['post_weight'] = empty($_REQUEST['weight']) ?
                null: (float)$_REQUEST['weight'];
            $post_comment = empty($_REQUEST['comment']) ?
                null: $_REQUEST['comment'];
            $args['post_comment']
                = _H($post_comment);
            if (strlen($args['post_year']) > 4) {
                $dbDef->add(__FILE__.":".__LINE__);
            }
            if (strlen($args['post_month']) > 2) {
                $dbDef->add(__FILE__.":".__LINE__);
            }
            if (strlen($args['post_day']) > 2) {
                $dbDef->add(__FILE__.":".__LINE__);
            }
            if (strlen($args['post_hour']) > 2) {
                $dbDef->add(__FILE__.":".__LINE__);
            }
            if (strlen($args['post_comment']) > 1000) {
                $dbDef->add(__FILE__.":".__LINE__);
            }
            if ($args['post_weight'] > 1000) {
                $dbDef->add(__FILE__.":".__LINE__);
            }
        }
    }        

    function prepare(&$args) {
        $button = empty($_REQUEST['button']) ? null: $_REQUEST['button'];
        $mode = empty($_REQUEST['mode']) ? null: $_REQUEST['mode'];
        $args['mode'] = $mode;
        if ($button == "更新") {
            $args['post_message'] = "更新しました。";
            $this->toDB("update", $args);
        } else if ($mode == "delete") {
            $args['post_message'] = "削除しました。";
            $this->toDB("delete", $args);
        }
        if ($mode == "jump") {
            $args['offset']
               = $this->get_offset($_REQUEST['jumpy'], $_REQUEST['jumpm']);
        } else {
            if (isset($_REQUEST['offset'])) {
                $args['offset'] = (int)$_REQUEST['offset'];
                $_SESSION['offset'] = $args['offset'];
            } else if (isset($_SESSION['offset'])) {
                $args['offset'] = $_SESSION['offset'];
            } else {
                $args['offset'] = 0;
            }
        }

        $this->set_start_and_end($args);
        $dbWeight = new DBWeight();
        $args['weights'] = $dbWeight->get($_SESSION['user_id'], 
                                          $this->start, $this->end);
    }
    
    function echo_head() {
        Page::echo_head(array("title" => "データ編集",
                             "refresh" => SESSION_LIFETIME + 120,
                             "style_sheet" =>"css/edit.css"));
    }

    function echo_body(&$args) {
?>
<h1>データ編集</h1>
<div id="first">
<p>
     <?php part_echo_navi("データ編集", false); ?>
</p>
</div> <!-- first -->

<div id="second">
  <?php 
     if (isset($args['post_message'])) $this->echo_post_message($args);
  ?>       
  <form action="<?= TOP_PAGE ?>" method="post">
    <?php user_echo_select_year("jumpy"); ?>
    <input type="text" name="jumpm" value="<?= Date("n") ?>"
        size="2" maxlength="2">月
    <input type="submit" value="ジャンプ">
    <input type="hidden" name="cmd" value="edit">
    <input type="hidden" name="mode" value="jump">
  </form>
<?php
    print "<h2>".$args['start_str']." -- ".$args['end_str']."</h2>\n";
    print "<p>\n";
    print "<a href=\"".TOP_PAGE."?cmd=edit&amp;offset=".($args['offset'] + 1)."\">".
        "前の週</a>\n";
    if ($args['offset'] != 0) {
        print "<a href=\"".TOP_PAGE."?cmd=edit&amp;offset=".($args['offset'] - 1)."\">".
        "次の週</a>\n";
    }
    print "</p>\n";
    if (count($args['weights']) == 0) {
        print "<p>この週のデータはありません</p>\n";
    }
    $i = 0;
    print "<form class=\"data\" action=\"" . TOP_PAGE . "\" method=\"post\">";
    foreach($args['weights'] as $row) {
        $class = $i % 2 ? "even" : "odd";
        $a = util_pgts2array($row['date_hour']);
        $weight = $row['weight'];
        $comment = _H($row['comment']);
?>
  <div class="<?= $class ?>">
    <?= sprintf("%2d月%2d日%2d時", 
               $a['month'], $a['day'], $a['hour']) ?>
    <input type="text" size="5" maxlength="5"
       name="weight<?= $i ?>" value="<?= $weight ?>">kg
    いいわけ<input type="text" size="20" maxlength="200"
       name="comment<?= $i ?>" value="<?= $comment ?>">
<?php
        $del_param = "cmd=edit&mode=delete";
        $del_param .= "&year=" . $a['year'];
        $del_param .= "&month=" . $a['month'];
        $del_param .= "&day=" . $a['day'];
        $del_param .= "&hour=" . $a['hour'];
?>
    <a href="<?= TOP_PAGE ?>?<?= $del_param ?>">削除</a>
    <input type="hidden" name="year<?= $i ?>" value="<?= $a['year'] ?>">
    <input type="hidden" name="month<?= $i ?>" value="<?= $a['month'] ?>">
    <input type="hidden" name="day<?= $i ?>" value="<?= $a['day'] ?>">
    <input type="hidden" name="hour<?= $i ?>" value="<?= $a['hour'] ?>">
  </div>
<?php
        $i++;
    } //foreach
?>
  <input type="submit" name="button" value="更新" id="update_button">
  <input type="hidden" name="cmd" value="edit">
  </form>
</div> <!-- second -->

<div id="third">
      <?php part_echo_navi("データ編集", false); ?>
</div> <!-- third -->
<?php
    } // echo_body()

    function echo_post_message($args) {
?>
<p>
  <span class="post_message"><?= _H($args['post_message']) ?></span>
  <?php if ($args['mode'] == "delete") { ?>            
    <?= _H($args['post_year']) ?>年<?= _H($args['post_month']) ?>月<?= _H($args['post_day']) ?>日
    <?= _H($args['post_hour']) ?>時
    <?= _H($args['post_weight']) ?>kg <?= _H($args['post_comment']) ?>
  <?php } ?>
</p>
<?php
    }
}

class UserPastPage extends Page {
    protected $need_auth = true;
    function echo_head() {
        Page::echo_head(array("title" => "過去データ",
                             "style_sheet" =>"css/past.css"));
    }

    function echo_body() {
?>
<h1>過去データ</h1>
<div id="first">
     <?php part_echo_navi("過去データ"); ?>
</div> <!-- first -->

<div id="second">
<?php
      weight_echo_past();
      if (!empty($_REQUEST['start'])) {
          weight_echo_comment();
      }
?>
</div> <!-- second -->
<?php
    } //echo_body()
}

class UserMassInputPage extends Page {
    protected $need_auth = true;
    var $done_input = false;

    function prepare() {
        $mode = empty($_REQUEST['mode']) ? null: $_REQUEST['mode'];
        if ($mode == "input") {
            $dbWeight = new DBWeight();
            $dbWeight->setMass();
            $this->done_input = true;
        }
    }
    function echo_head() {
        Page::echo_head(array("title" => "まとめ入力",
                             "style_sheet" =>"css/mass_input.css"));
    }
    function echo_body() {
?>
<h1>まとめ入力</h1>
<div id="first">
  <?php part_echo_navi("まとめ入力", false); ?>
</div> <!-- first -->

<div id="second">
  <?php if ($this->done_input) $this->echo_input_result();?>
  <div class="input">
  <form class="input" action="<?= TOP_PAGE ?>" method="post">
   <p>
     <?php
        user_echo_select_year();
        $month = date("n");
        $day = "";
        $hour = "";
     ?>
     <input type="text" name="month" value="<?= $month ?>"
          size="2" maxlength="2">月
   </p>
     <?php
        for($i = 0; $i < NUM_MASS_INPUT; $i++) {
            $class = $i % 2 ? "even" : "odd";
     ?>
   <div class="<?= $class ?>">
     <input type="text" name="day<?= $i ?>" value="<?= $day ?>"
          size="2" maxlength="2">日
     <input type="text" name="hour<?= $i ?>" value="<?= $hour ?>"
           size="2" maxlength="2">時
     <input type="text" name="weight<?= $i ?>" value="" size="5" maxlength="5">kg
     いいわけ <input type="text" name="comment<?= $i ?>" value="" size="20" maxlength="200">
   </div>
   <?php
        } //for
   ?>
   <input type="submit" value="登録">
   <input type="hidden" name="cmd" value="mass_input">
   <input type="hidden" name="mode" value="input">
  </form>
  </div> <!-- input -->
</div> <!-- second -->

<div id="third">
  <?php part_echo_navi("まとめ入力", false); ?>
</div> <!-- third -->
<?php
    }

    function echo_input_result() {
?>
  <span class="input_result">正常に登録しました。</span>
<?php
    }
}

class UserImageSettingPage extends Page {
    protected  $need_auth = true;

    var $gif = GIF_ON;
    var $width = GRAPH_WIDTH;
    var $height = GRAPH_HEIGHT;
    var $mob_width = MOB_GRAPH_WIDTH;
    var $mob_height = MOB_GRAPH_HEIGHT;

    function prepare(&$args) {
        $dbUC = new DBUserConf();
        $conf = $dbUC->getAll();

        if ($conf['gif'] == GIF_ON) {
            $args['gif'] = GIF_ON;
        } else {
            $args['gif'] = "";
        }
        if (!empty($conf['width'])) {
            $args['width'] = $conf['width'];
        }
        if (!empty($conf['height'])) {
            $args['height'] = $conf['height'];
        }
        if (!empty($conf['mob_width'])) {
            $args['mob_width'] = $conf['mob_width'];
        }
        if (!empty($conf['mob_height'])) {
            $args['mob_height'] = $conf['mob_height'];
        }
    }

    function echo_head() {
        Page::echo_head(array("title" => "画像設定",
                             "style_sheet" =>"css/image_setting.css"));
    }

    function echo_body(&$args) {
?>
<h1>画像設定</h1>
<div id="first">
     <?php part_echo_navi("画像設定"); ?>
</div> <!-- first -->

<div id="second">
  <form action="<?= TOP_PAGE ?>" method="post">
    <p>
      画像形式:
       <input type="radio" name="gif" value="0"
             <?= ($args['gif'] != GIF_ON) ? "checked" : "" ?>>PNG
       <input type="radio" name="gif" value="<?= GIF_ON ?>"
             <?= ($args['gif'] == GIF_ON) ? "checked" : "" ?>>GIF
    </p>
    <p>
      横幅:
       <input type="text" name="width" value="<?= _H($args['width']) ?>"
                                           size="4" maxlengh="4">
      縦幅:
       <input type="text" name="height" value="<?= _H($args['height']) ?>"
                                          size="4" maxlengh="4">
    </p>
    <p>
      携帯用
      横幅:
       <input type="text" name="mob_width" value="<?= _H($args['mob_width']) ?>"
                                           size="4" maxlengh="4">
      縦幅:
       <input type="text" name="mob_height" value="<?= _H($args['mob_height']) ?>"
                                          size="4" maxlengh="4">
    </p>
    <p>
       <input type="submit" value="更新">
       <input type="hidden" name="cmd" value="do_image_setting">
    </p>
  </form>
</div> <!-- second -->
<?php
    } //echo_body();
}

class UserDoImageSettingPage extends Page {
    protected $need_auth = true;
    function prepare() {
        $dbUC = new DBUserConf();
        $dbUC->set();
    }

    function echo_head() {
        Page::echo_head(array("title" => "画像設定完了",
                         "style_sheet" =>"css/do_image_setting.css"));
    }

    function echo_body(&$args) {
        $dbUC = new DBUserConf();
        $conf = $dbUC->getAll();
?>
<h1>更新しました。</h1>
<div id="first">
        <?php part_echo_navi(""); ?>
</div> <!-- first -->

<div id="second">
  <p>
      画像形式: <?= ($conf['gif'] == GIF_ON) ? "GIF" : "PNG" ?>
  </P>
  <p>
      横幅：<?= $conf['width'] ?> 縦幅: <?= $conf['height'] ?>
  </p>
  <p>
      携帯用 横幅：<?= $conf['mob_width'] ?> 縦幅: <?= $conf['mob_height'] ?>
  </p>
</div> <!-- second -->
<?php
    }  //echo_body()
}

class UserDoEntryPage extends Page {
    function prepare() {
        $username = $_REQUEST['username'];
        $password1 = $_REQUEST['password1'];
        $password2 = $_REQUEST['password2'];
        $dbh = DietDB::getHandler();
        $dbDef = new DBDefense($dbh);

        if (empty($username)) {
            error_show_empty_username();
            return;
        }
        if (empty($password1) || empty($password2)) {
            error_show_empty_password();
            return;
        }
        if (strlen($username) > 16) {
            $dbDef->add(__FILE__.":".__LINE__);
            return;
        }
        if (strlen($password1) > 16) {
            $dbDef->add(__FILE__.":".__LINE__);
        }
        if (!user_isValidUsername($username)) {
            error_show_illegal_username();
            return;
        }
        if ($password1 != $password2) {
            error_show_not_match_password();
            return;
        }
        if (!user_isValidPassword($password1)) {
            error_show_illegal_password();
            return;
        }
        $dbUsers = new DBUsers($dbh);
        if (!$dbUsers->isUniqueUsername($username)) {
            error_show_not_unique_username();
            return;
        }
        $dbUsers->add($username, $password1);
        $dbOpe = new DBOperation();
        $dbOpe->add(OPE_USER_ENTRY);
    }

    function echo_head() {
        Page::echo_head(array("title" => "ユーザ登録完了",
                             "style_sheet" =>"css/do_entry.css"));
    }

    function echo_body() {
?>
<h1>ユーザ登録完了</h1>
<p>
  ユーザ登録ができました。
</p>
<p>
  トップページからログインして下さい。
</p>        
<p>
  <a href="<?= TOP_PAGE ?>">トップページ</a>
</p>
<?php
   } //echo_body()
}

class UserCSVPage extends Page {
    protected $need_auth = true;
    
    function prepare(&$args) {
        $mode = empty($_REQUEST['mode']) ? null: $_REQUEST['mode'];
    }

    function echo_head() {
        Page::echo_head(array("title" => "CSVのダウンロード",
                             "refresh" => SESSION_LIFETIME + 120,
                             "style_sheet" =>"css/csv.css"));
    }

    function echo_body(&$args) {
?>
<h1>CSVの取得</h1>
<div id="first">
  <?php part_echo_navi("CSVで取得"); ?>
</div> <!-- first -->

<div id="second">
<p>
<form action="<?= CSV_PAGE ?>" method="post">
  <input type="submit" value="CSVのダウンロード">
</form>
</p>
</div> <!-- second -->

<div id="third">
<p>
     <?php part_echo_navi("自分のページ", false); ?>
</p>
</div>
<?php
     }  //echo_body()
}

function user_isValidUsername($username) {
    return preg_match("/^[[:alnum:]]+$/", $username);
}

function user_isValidPassword($password) {
    return preg_match("/^[[:alnum:]]+$/", $password);
}


?>
