<?php
require_once("page/page.inc.php");
require_once("pub/DBPubFriend.class.php");
require_once("user/User.class.php");
require_once("defense/DBDefense.class.php");
require_once("util/_H.inc.php");



class UserFriendSettingPage extends Page {
    protected $need_auth = true;
    protected $dbh;
    protected $dbUsers;

    function prepare(&$args) {
        $this->dbh = DietDB::getHandler();
        $this->dbUsers = new DBUsers($this->dbh);
        $dbPF = new DBPubFriend($this->dbh);

        $user = new User($_SESSION['user_id'], $this->dbh);
        $user->load();

        $mode = empty($_REQUEST['mode']) ? null: $_REQUEST['mode'];
        if ($mode == "input_first_self") {
            $user->name_for_friend
                = $this->check_name_for_friend();
            $user->id_for_friend = $this->get_id();
            $user->update();
        }
        if ($mode == "input_self") {
            if (isset($_REQUEST['name_button'])) {
                $user->name_for_friend
                    = $this->check_name_for_friend();
                $user->update();
                $args['message'] = "名前を変更しました。";
            }
            if (isset($_REQUEST['id_button'])) {
                $user->id_for_friend = $this->get_id();
                $user->update();
                $args['message'] = "秘密IDを再発行しました。";
            }
        }
        if ($mode == "input_friend") {
            if (strlen($_REQUEST['fid']) != 32) {
                error_show_no_friend_id();
            }
            $users_id = $this->dbUsers->getByIdForFriend($_REQUEST['fid']);
            if ($users_id <= 0) {
                error_show_no_friend_id();
            }
            $dbPF->add($_REQUEST['fid']);
            $args['message'] = "お仲間を追加しました。";
        }
        if ($mode == "delete") {
            $dbPF->delete($_REQUEST['fid']);
            $args['message'] = "お仲間を削除しました。";
        }

        $args['name_for_friend'] = $user->name_for_friend;
        $args['id_for_friend'] = $user->id_for_friend;
        $args['pub_name'] = $user->pub_name;
        $args['friends'] = $dbPF->get();
         
    }

    function echo_head() {
        Page::echo_head(array("title" => "お仲間の設定", 
                             "style_sheet" =>"css/user_friend.css"));
    }

    function echo_body(&$args) {
?>
<h1>お仲間の設定</h1>
<div id="first">
     <?php part_echo_navi("お仲間の設定"); ?>
</div>

<div id="second">
<?php
         if (!empty($args['message'])) {
             print("<p>"._H($args['message'])."</p>\n");
         }
?> 
<h2>自分の設定</h2>
<p>
     仲間内での名前を登録すると、秘密IDが表示されます。<br>
     それをe-mailで教えあって登録して下さい。
</p>
<?php
         if (empty($args['name_for_friend'])) {
             $this->echo_no_name($args);
         } else {
             $this->echo_name_exists($args);
         }
?> 
<h2>お仲間登録</h2>
<form class="friend" method="post" action="<?= TOP_PAGE ?>">
  <p>
      追加するお仲間の秘密ID:<br>
      <input type="text" name="fid"
             size="32" maxlength="32">
      <input type="submit" name="id_button" value="追加">
  </p>
  <input type="hidden" name="cmd" value="friend_setting">
  <input type="hidden" name="mode" value="input_friend">
</from>
<?php
         foreach($args['friends'] as $friend_id => $friend_name) {
?>
  <a href="<?= TOP_PAGE ?>?cmd=friend&amp;fid=<?= _H($friend_id) ?>">
       <?= _H($friend_name) ?>: <?= _H($friend_id) ?>
  </a>&nbsp;
  <a href="<?= TOP_PAGE ?>?cmd=friend_setting&amp;mode=delete&amp;fid=<?= _H($friend_id) ?>">
       削除
  </a>
  <br>
<?php
         }
?>
</div> <!-- second -->
<?php
    }

    function echo_no_name(&$args) {
?>
<form class="secret" method="post" action="<?= TOP_PAGE ?>">
  <p>
  仲間内での名前:  <input type="text" size="20" maxlength="40"
     name="name_for_friend" value="<?= _H($args['pub_name']) ?>">
      <input type="submit" name="name_button" value="登録">
  </p>
  <input type="hidden" name="cmd" value="friend_setting">
  <input type="hidden" name="mode" value="input_first_self">
</form>
<?php
     }

    function echo_name_exists(&$args) {
?>
<form class="secret" method="post" action="<?= TOP_PAGE ?>">
  <p>
  仲間内での名前:  <input type="text"  size="20" maxlength="40" name="name_for_friend" value="<?= _H($args['name_for_friend']) ?>">
      <input type="submit" name="name_button" value="変更">
  </p>
  <p>
      自分の秘密ID:<br>
      <?= _H($args['id_for_friend']) ?>
      <input type="submit" name="id_button" value="再発行">
  </p>
  <input type="hidden" name="cmd" value="friend_setting">
  <input type="hidden" name="mode" value="input_self">
</form>
<?php
    }

    function check_name_for_friend() {
        $name = trim($_REQUEST['name_for_friend']);
        if (strlen($name) > 100) {
            $dbDef = new DBDefense($this->dbh);
            $dbDef->add(__FILE__.":".__LINE__);
        }
        if (empty($name)) {
            error_show_empty_name_for_friend();
        }
        return $name;
    }

    function get_id() {
        $id_for_friend = md5(uniqid(rand(),1));
        while ($this->dbUsers->getByIdForFriend($id_for_friend) > 0) {
            $id_for_friend = md5(uniqid(rand(),1));
        }
        return $id_for_friend;
    }
}
?>