<?php
require_once("db/DietDB.class.php");
require_once("def/def_conf.inc.php");
require_once("user/DBUsers.class.php");
require_once("defense/DBDefense.class.php");
require_once("util/util.inc.php");
require_once("error/error.inc.php");
require_once("weight/weight.inc.php");

class DBWeight {
    protected $dbh;
    protected $dbDef;

    function __construct($dbh = null) {
        if ($dbh == null) {
            $this->dbh = DietDB::getHandler();
        } else {
            $this->dbh = $dbh;
        }
        $this->dbDef = new DBDefense($this->dbh);
    }

    protected function doSet($date_hour, $weight, $comment) {
        $users_id = $_SESSION['user_id'];
        $stmt = $this->dbh->prepare("select users_id from weight_data ".
                                    "where users_id = ? and date_hour = ?;");
        $stmt->execute(array($users_id, $date_hour));
        $flag = $stmt->fetchColumn();
        if ($flag) {
            $stmt = $this->dbh->prepare("update weight_data set weight = ?, ".
                                        "  comment = ?, ".
                                        "  up_date = current_timestamp ".
                                        "where users_id = ? and ".
                                        "  date_hour = ?;");
            $stmt->execute(array($weight, $comment, $users_id, $date_hour));
        } else {
            $stmt = $this->dbh->prepare("insert into weight_data".
                                        "(users_id, date_hour, ".
                                        "  weight, comment) ".
                                        "values(?, ?, ?, ?);");
            $stmt->execute(array($users_id, $date_hour, $weight, $comment));
        }
        $dbUsers = new DBUsers($this->dbh);
        $dbUsers->setUpDate($users_id);
    }

    function set() {
        $year = (int)$this->getYear($_REQUEST['year']);
        $month = (int)$this->getMonth($_REQUEST['month']);
        $day = (int)$this->getDay($_REQUEST['day']);
        $hour = (int)$this->getHour($_REQUEST['hour']);
        $weight = (float)$this->getWeight($_REQUEST['weight']);
        $comment = rtrim($this->getComment($_REQUEST['comment']));

        $php_date_hour = mktime($hour, 0, 0, $month, $day, $year);
        if ($php_date_hour > time()) {
            error_show_future();
            exit;
        }
        $date_hour = util_php2pgts($php_date_hour);
        
        $this->doSet($date_hour, $weight, $comment);
    }

    function setMass() {
        for ($i = 0; true; $i++) {
            $name_year = empty($_REQUEST['year']) ? "year" . $i : "year";
            $name_month = empty($_REQUEST['month']) ? "month" . $i : "month";
            $name_day = "day" . $i;
            $name_hour = "hour" . $i;
            $name_weight = "weight". $i;
            $name_comment = "comment" .$i;

            if (empty($_REQUEST[$name_year]) || empty($_REQUEST[$name_month])
                || empty($_REQUEST[$name_day]) || empty($_REQUEST[$name_hour])
                || empty($_REQUEST[$name_weight])) {
                break;
            }

            $year = (int)$this->getYear($_REQUEST[$name_year]);
            $month = (int)$this->getMonth($_REQUEST[$name_month]);
            $day = (int)$this->getDay($_REQUEST[$name_day]);
            $hour = (int)$this->getHour($_REQUEST[$name_hour]);
            $weight = (float)$this->getWeight($_REQUEST[$name_weight]);
            $comment = rtrim($this->getComment($_REQUEST[$name_comment]));
            
            $php_date_hour = mktime($hour, 0, 0, $month, $day, $year);
            if ($php_date_hour > time()) {
                error_show_future();
                exit;
            }
            $date_hour = util_php2pgts($php_date_hour);
            
            $this->doSet($date_hour, $weight, $comment);
        }
    }

    function delete() {
        $year = (int)$this->getYear($_REQUEST['year']);
        $month = (int)$this->getMonth($_REQUEST['month']);
        $day = (int)$this->getDay($_REQUEST['day']);
        $hour = (int)$this->getHour($_REQUEST['hour']);
        $users_id = $_SESSION['user_id'];

        $pgts = $year."-".$month."-".$day." ".$hour.":0:0";
        
        $stmt = $this->dbh->prepare("delete from  weight_data ".
                                    "where users_id = ? and date_hour = ?;");
        $stmt->execute(array($users_id, $pgts));
    }

    function get($users_id, $start, $end) {
        $pg_start = util_php2pgts($start);
        $pg_end = util_php2pgts($end);
        $stmt = $this->dbh->prepare("select date_hour, weight, comment ". 
                                    "from weight_data ".
                                    "where users_id = ? and ".
                                    "  date_hour >= ? and date_hour < ? ".
                                    "order by date_hour;");
        $stmt->execute(array($users_id, $pg_start, $pg_end));
        $res = $stmt->fetchAll(PDO::FETCH_ASSOC);
        if ($res) {
            return $res;
        } else {
            return array();
        }
    }

    function getComments($users_id, $start, $end) {
        $pg_start = util_php2pgts($start);
        $pg_end = util_php2pgts($end);
        $stmt = $this->dbh->prepare("select date_hour, comment from weight_data ".
                                    "where users_id = ? and comment <> '' and ".
                                    "  date_hour >= ? and date_hour < ? ".
                                    "order by date_hour;");
        $stmt->execute(array($users_id, $pg_start, $pg_end));
        $comments = $stmt->fetchAll(PDO::FETCH_ASSOC);
        return $comments;
    }

    function getRecentAndOld($users_id) {
        $stmt = $this->dbh->prepare("select min(date_hour) as min, ". 
                                    "  max(date_hour) as max ".
                                    "from weight_data ".
                                    "where users_id = ?;");
        $stmt->execute(array($users_id));
        $exists = false;
        while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
            if ($row['min'] && $row['max']) {
                $old = util_pgts2php($row['min']);
                $recent = util_pgts2php($row['max']);
                $exists = true;
            }
        }
        if ($exists) {
            $a = array('recent' => $recent, 'old' => $old);
            return $a;
        }
        return null;
    }    

    function exists($users_id, $year, $month) {
        $pgts_start = util_php2pgts(mktime(0, 0, 0, $month, 1, $year));
        $pgts_end = util_php2pgts(mktime(0, 0, 0, $month + 1, 1, $year));
        $stmt = $this->dbh->prepare("select users_id from weight_data ".
                                    "where users_id = ? and ".
                                    "  date_hour >= ? and date_hour < ?;");
        $stmt->execute(array($users_id, $pgts_start, $pgts_end));
        $flag = $stmt->fetchColumn();
        if ($flag) {
            return true;
        }
        return false;
    }

    function getCount($users_id) {
        $stmt = $this->dbh->prepare("select count(*) from weight_data ".
                                    "where users_id = ?;");
        $stmt->execute(array($users_id));
        return $stmt->fetchColumn();
    }

    function getCountInMonth($users_id) {
        $end = util_next_day(time());
        $wr = new WeightRange("1m");
        $start = $wr->getStart($end);
    
        $pgts_start = util_php2pgts($start);
        $pgts_end = util_php2pgts($end);

        $stmt = $this->dbh->prepare("select count(*) from weight_data ".
                                    "where users_id = ? and ".
                                    "  date_hour >= ? and date_hour < ?;");
        $stmt->execute(array($users_id, $pgts_start, $pgts_end));
        return $stmt->fetchColumn();
    }

    function getAll($users_id) {
        $stmt = $this->dbh->prepare("select * from weight_data ".
                                    "where users_id = ? " . 
                                    "order by date_hour;");
        $stmt->execute(array($users_id));
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }


        

    protected function getYear($year) {
        $year = (int)$year;
        if ($year < (int)START_YEAR || $year > (int)date("Y")) {
            error_show_year();
            exit;
        }
        return $year;
    }
    protected function getMonth($month) {
        $month = (int)$month;
        if ($month < 1 || $month > 12) {
            error_show_month();
            exit;
        }
        return $month;
    }
    protected function getDay($day) {
        $day = (int)$day;
        if ($day < 1 || $day > 31) {
            error_show_day();
            exit;
        }
        return $day;
    }
    protected function getHour($hour) {
        $hour = (int)$hour;
        if ($hour < 0 || $hour > 23) {
            error_show_hour();
            exit;
        }
        return $hour;
    }
    protected function getWeight($weight) {
        $weight = preg_replace("/。/", ".", $weight);
        $weight = (float)$weight;
        if ($weight <= 0 || $weight > 1000) {
            error_show_weight();
            exit;
        }
        return $weight;
    } 
    protected function getComment($comment) {
        if (mb_strlen($comment) > 1000) {
            $this->dbDef_add(__FILE__.":".__LINE__);
        }
        return $comment;
    }

    function getYears($min, $max) {
        $year_min = date("Y", $min);
        $year_max = date("Y", $max);
        $yaers = array();
        for ($i = $year_min ; $i <= $year_max; $i++) {
            $years[] = $i;
        }
        return $years;
    }
}

class old_WeightDBData {
    protected $users_id;
    protected $data;
    protected $start;

    function WeightDBData($users_id) {
        $this->users_id = $users_id;
        $this->data = array();
    }

    function loadData($start, $end) {
        $this->start = $start;
        $pg_start = util_php2pgts($start);
        $pg_end = util_php2pgts($end);
        $stmt = $this->dbh->prepare("select date_hour, weight ".
                                    "from weight_data ".
                                    "where users_id = ? and ".
                                    "  date_hour >= ? and date_hour < ? ".
                                    "order by date_hour;");
        $stmt->execute(array($this->users_id, $pg_start, $pg_end));
        $i = 0;
        while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
            $php_date_hour = util_pgts2php($row['date_hour']);
            if ($i == 0) {
                $this->start = $php_date_hour;
            }
            $weight = $row['weight'];
            $this->data[$php_date_hour] = $weight;
            $i++;
        }
    }
}
?>
