<?php
require_once("weight/DBWeight.class.php");
require_once("weight/weight_graph.inc.php");
require_once("user/UserStatus.class.php");
require_once("user/DBUserConf.class.php");
require_once("util/util.inc.php");
require_once("error/error.inc.php");

function weight_echo_graph() {
    $dbh = DietDB::getHandler();
    $us = new UserStatus($dbh);
    $user = $us->user;
    if ($us->is_pub) {
        $next_cmd = "pub";
        $name_pubname = htmlspecialchars($user->pub_name);
    } else if ($us->is_friend) {
        $next_cmd = "friend";
        $name_pubname = htmlspecialchars($user->name_for_friend);
    } else {
        $next_cmd = "user";
        $pub_name = $user->public == "t" ? $user->pub_name : "非公開";
        $pub_name = htmlspecialchars($pub_name);
        $name = htmlspecialchars($user->name);
        $name_pubname = $name . "(" . $pub_name . ")";
    }

    $range = weight_get_range();
    $width = weight_get_graph_width($dbh);
    $height = weight_get_graph_height($dbh);
    $div = weight_is_divide() ? "t": "f";
/* for php5    
    $graph_param = http_build_query(array('puid' => $pou-puid, 
'fid' => $pou-fid) , 'range' => $range, 'div' => $div);
*/
    $graph_param = "puid=".$us->puid;
    $graph_param .= "&fid=".$us->fid;
    $graph_param .= "&range=".$range;
    $graph_param .= "&div=".$div;
    $graph_ref = WEIGHT_GRAPH . "?" . htmlspecialchars($graph_param);

    $page_param = "cmd=" . $next_cmd;
    $page_param .= "&puid=" . $us->puid;
    $page_param .= "&fid=" . $us->fid;
    $page_param .= "&div=" . $div;
    $ref = TOP_PAGE . "?" . htmlspecialchars($page_param);
    $one_week = "<a href=\"$ref&amp;range=1w\">1週間</a>\n";
    $two_week = "<a href=\"$ref&amp;range=2w\">2週間</a>\n";
    $one_month = "<a href=\"$ref&amp;range=1m\">1ヶ月</a>\n";
    $three_month = "<a href=\"$ref&amp;range=3m\">3ヶ月</a>\n";
    $one_year = "<a href=\"$ref&amp;range=1y\">1年</a>\n";
    if ($range == "1w") $one_week = "<1週間>\n";
    if ($range == "2w") $two_week = "<2週間>\n";
    if ($range == "1m") $one_month = "<1ヶ月>\n";
    if ($range == "3m") $three_month = "<3ヶ月>\n";
    if ($range == "1y") $one_year = "<1年>";

    $page_param2 = "cmd=" . $next_cmd;
    $page_param2 .= "&puid=" . $us->puid;
    $page_param2 .= "&fid=" . $us->fid;
    $page_param2 .= "&range=" . $range;
    $ref = TOP_PAGE . "?" . htmlspecialchars($page_param2);
    $div_no =  ($div != "t") ?
        "<分離しない>\n" : "<a href=\"$ref&amp;div=f\">分離しない</a>\n";
    $div_yes = ($div == "t") ?
        "<分離する(昼は赤、夜は青)>\n"
        : "<a href=\"$ref&amp;div=t\">分離する(昼は赤、夜は青)</a>\n";
     
    $sid = htmlspecialchars(SID);
?>
<div class="graph">
<p>
  <a href="<?= $graph_ref ?>">
    <img src="<?= $graph_ref ?>&amp;<?= $sid ?>"
       alt="<?= $name_pubname ?>の体重グラフ"
       width="<?= $width ?>" height="<?= $height ?>">
  </a>
</p>
<p>
  表示範囲: <?= $one_week ?> <?= $two_week ?> <?= $one_month ?> <?= $three_month ?> <?= $one_year ?><br>
</p>
<p>
  昼夜分離: <?= $div_no ?> <?= $div_yes ?> <br>
</p>
</div> <!-- graph -->
<?php
}

function weight_echo_comment() {
    print "<h2>いいわけ</h2>\n";
    $us = new UserStatus();
    
    if (!empty($_REQUEST['start'])) {
        $start = weight_datestr_to_php($_REQUEST['start']);
        $wr = new WeightRange("1m");
        $end = $wr->getEnd($start);
    } else {
        $range = weight_get_range();
        $wr = new WeightRange($range);
        $end = util_next_day(time());
        $start = $wr->getStart($end);
    }
    $dbWeight = new DBWeight();
    $comments = $dbWeight->getComments($us->users_id, $start, $end);
    $i = 0;
    foreach($comments as $c) {
        $date_hour = $c['date_hour'];
        $comment = $c['comment'];
        $a =& util_pgts2array($date_hour);
        $class = $i % 2 ? "even" : "odd";
        if ($i == 0) {
            $old_month = $a['month'];
            print "<h3>".$a['year']."年".$a['month']."月</h3>\n";
            print "<table>\n";
        }
        $new_month = $a['month'];
        if ($old_month != $new_month) {
            $old_month = $new_month;
            print "</table>\n";
            print "<h3>".$a['year']."年".$a['month']."月</h3>\n";
            print "<table>\n";
        }
        print "<tr class=\"$class\">\n";
        print "<td>".$a['day']."日".$a['hour']."時</td>\n";
        $comment = util_wordwrap($comment, 35);
        $comment = htmlspecialchars($comment);
        $comment =& util_nl2br($comment);
        print "<td>$comment</td>\n";
        print "</tr>\n";
        $i++;
    }
    print "</table>\n";
}

function weight_echo_past() {
    $dbh = DietDB::getHandler();
    $us = new UserStatus($dbh);
    $dbWeight = new DBWeight($dbh);
    $ro = $dbWeight->getRecentAndOld($us->users_id);
    if ($ro) {
        $years = $dbWeight->getYears($ro['old'], $ro['recent']);
    } else {
        $years = array();
    }

    $range = weight_get_range();

    print "<div class=\"years\">\n";
    if (count($years) == 0) {
        print "<p>データはありません。</p>\n";
    }
    foreach($years as $year) {
        weight_echo_1year($us, $year);
        for ($i = 1; $i <= 12; $i++) {
            weight_echo_month($us, $year, $i);
        }
        print "<br>\n";
        for ($i = 1; $i < 12; $i += 3) {
            weight_echo_3month($us, $year, $i);
        }
        print "<br>\n";
    }         
    print "</div> <!-- years -->\n";

    if (empty($_REQUEST['start'])) return;
    
    $user = $us->user;
    if ($us->is_pub) {
        $name_pubname = htmlspecialchars($user->pub_name);
    } else if ($us->is_friend) {
        $name_pubname = htmlspecialchars($user->name_for_friend);
    } else {
        $pub_name = $user->public == "t" ? $user->pub_name : "非公開";
        $name_pubname = $user->name."(".$pub_name.")";
    }

    $width = weight_get_graph_width($dbh);
    $height = weight_get_graph_height($dbh);

    $param = "puid=$us->puid";
    $param .= "&fid=$us->fid";
    $param .= "&range=$range";
    $param .= "&start=" . $_REQUEST['start'];
    $graph_ref = htmlspecialchars(WEIGHT_GRAPH . "?" . $param);
    $pdf_ref = htmlspecialchars(PDF_PAGE . "?" . $param);
    $sid = htmlspecialchars(SID);

    if (PDF_ON && !empty($_REQUEST['start'])) {
        print "<a href=\"$pdf_ref\">印刷用PDF</a><br>\n";
    }

    print "<div class=\"graph\">\n";
    print "<a href=\"$graph_ref\">\n";
    print "  <img src=\"$graph_ref&amp;$sid\"\n";
    print "    alt=\"".$name_pubname."の体重グラフ\" ";
    print "    width=\"$width\" height=\"$height\">\n";
    print "</a>\n";
    print "</div> <!-- graph -->\n";

}

function weight_echo_month($us, $year, $month) {
    $graph = false;
    $dbWeight = new DBWeight();
    if (!$dbWeight->exists($us->users_id, $year, $month)) {
        print "[$month]\n";
        return;
    }

    $range = weight_get_range();
    $datestr = "$year.$month.1";
    if (!empty($_REQUEST['start']) && $range == "1m") {
        $start = weight_datestr_to_php($_REQUEST['start']);
        $req_year = Date("Y", $start);
        $req_month = Date("n", $start);
        if ($year == $req_year && $month == $req_month) {
            $graph = true;
        } 
    }
    if ($graph) {
        print "<$month>\n";
    } else {
        if ($us->is_pub) {
            $params = "cmd=pub_past&amp;puid=$us->puid&amp;";
        } else if ($us->is_friend) {
            $params = "cmd=friend_past&amp;fid=$us->fid&amp;";
        } else {
            $params = "cmd=past&amp;";
        }
        print "<a href=\"".TOP_PAGE."?$params"."range=1m&amp;start=$datestr\">".
                "[$month]</a>\n";
    }
}

function weight_echo_3month($us, $year, $month) {
    $end_month = $month + 2;
    $graph = false;
    $exist_data = false;
    $dbWeight = new DBWeight();
    for ($i = 0; $i < 3; $i++) {
        if ($dbWeight->exists($us->users_id, $year, $month + $i)) {
            $exist_data = true;
            break;
        }
    }
    if (!$exist_data) {
        print "[$month-$end_month]";
        return;
    }
    
    $range = weight_get_range();
    $datestr = "$year.$month.1";
    if (!empty($_REQUEST['start']) && $range == "3m") {
        $start = weight_datestr_to_php($_REQUEST['start']);
        $req_year = Date("Y", $start);
        $req_month = Date("n", $start);
        if ($year == $req_year && $month == $req_month) {
            $graph = true;
        } 
    }
    if ($graph) {
        print "<$month-$end_month>";
    } else {
        if ($us->is_pub) {
            $params = "cmd=pub_past&amp;puid=$us->puid&amp;";
        } else if ($us->is_friend) {
            $params = "cmd=friend_past&amp;fid=$us->fid&amp;";
        } else {
            $params = "cmd=past&amp;";
        }
        print "<a href=\"".TOP_PAGE."?$params"."range=3m&amp;start=$datestr\">".
                "[$month-$end_month]</a>\n";
    }
}

function weight_echo_1year($us, $year) {
    $graph = false;
    $exist_data = false;
    $dbWeight = new DBWeight();
    for ($i = 1; $i <= 12; $i++) {
        if ($dbWeight->exists($us->users_id, $year, $i)) {
            $exist_data = true;
            break;
        }
    }
    if (!$exist_data) {
        print $year."年<br>\n";
        return;
    }

    $range = weight_get_range();
    $datestr = "$year.1.1";
    if (!empty($_REQUEST['start']) && $range == "1y") {
        $start = weight_datestr_to_php($_REQUEST['start']);
        $req_year = Date("Y", $start);
        if ($year == $req_year) {
            $graph = true;
        } 
    }
    if ($graph) {
        print "<".$year."年><br>";
    } else {
        if ($us->is_pub) {
            $params = "cmd=pub_past&amp;puid=$us->puid&amp;";
        } else if ($us->is_friend) {
            $params = "cmd=friend_past&amp;fid=$us->fid&amp;";
        } else {
            $params = "cmd=past&amp;";
        }
        print "<a href=\"".TOP_PAGE."?".$params.
            "range=1y&amp;start=$datestr\">".
            $year."年</a><br>\n";
    }
}

function weight_get_graph_width($dbh) {
    if (!empty($_REQUEST['w'])) {
        $width = (int)$_REQUEST['w'];
        if ($width > 10 && $width < 10000) {
            return $width;
        }
    }
        
    $dbUC = new DBUserConf($dbh);
    if (empty($_REQUEST['mob']) || $_REQUEST['mob'] != 1) {
        $width = $dbUC->get('width');
        if (empty($width)) {
            $width = GRAPH_WIDTH;
        } 
    } else {
        $width = $dbUC->get('mob_width');
        if (empty($mob_width)) {
            $width = MOB_GRAPH_WIDTH;
        }
    }
    return $width;
}
function weight_get_graph_height($dbh) {
    if (!empty($_REQUEST['h'])) {
        $height = (int)$_REQUEST['h'];
        if ($height > 10 && $height < 10000) {
            return $height;
        }
    }

    $dbUC = new DBUserConf($dbh);
    if (empty($_REQUEST['mob']) || $_REQUEST['mob'] != 1) {
        $height = $dbUC->get('height');
        if (empty($height)) {
            $height = GRAPH_HEIGHT;
        }
    } else {
        $height = $dbUC->get('mob_height');
        if (empty($mob_height)) {
            $height = MOB_GRAPH_HEIGHT;
        }
    }
    return $height;
}

function weight_get_range() {
    if (!empty($_REQUEST['range'])) {
        return $_REQUEST['range'];
    } else if (!empty($_SESSION['range'])) {
        return $_SESSION['range'];
    }
    return "1w";
}

function weight_is_divide() {
    if (!empty($_REQUEST['div'])) {
        if ($_REQUEST['div'] == "t") {
            return true;
        } else {
            return false;
        }
    }
    if (!empty($_SESSION['div'])) {
        if ($_SESSION['div'] == "t") {
            return true;
        } else {
            return false;
        }
    }
    return false;
}

function weight_datestr_to_php($datestr) {
    $d = explode(".", $datestr);
    for ($i = 0; $i < 6; $i++) {
        $d[$i] = empty($d[$i]) ? 0 : $d[$i]; 
    }
    return mktime($d[3], $d[4], $d[5], $d[1], $d[2], $d[0]);
}

class WeightRange {
    var $range;
    var $interval;
    var $range_str;

    function WeightRange($range) {
        switch($range) {
        case "2w":
            $this->range = "2w";
            $this->interval = 3600 * 24;
            $this->range_str = "2週間";
            return;
        case "1m":
            $this->range = "1m";
            $this->interval = 3600 * 48;
            $this->range_str = "1ヶ月";
            return;
        case "3m";
            $this->range = "3m";
            $this->interval = 3600 * 144;
            $this->range_str = "3ヶ月";
            return;
        case "1y":
            $this->range = "1y";
            $this->interval = 3600 * 576;
            $this->range_str = "1年";
            return;
        case "1w":
        default:
            $this->range = "1w";
            $this->interval = 3600 * 24;
            $this->range_str = "1週間";
            return;
        }
    }
    function getStart($end) {
        $year = date("Y", $end);
        $month = date("n", $end);
        $day = date("j", $end);
        switch($this->range) {
        case "2w":
            return mktime(0, 0, 0, $month, $day - 14, $year);
        case "1m":
            return mktime(0, 0, 0, $month - 1, $day, $year);
        case "3m";
            return mktime(0, 0, 0, $month - 3, $day, $year);
        case "1y";
            return mktime(0, 0, 0, $month, $day, $year - 1);
        case "1w":
        default:
            return mktime(0, 0, 0, $month, $day - 7, $year);
        }
    }
    function getEnd($start) {
        $year = date("Y", $start);
        $month = date("n", $start);
        $day = date("j", $start);
        switch($this->range) {
        case "2w":
            return mktime(0, 0, 0, $month, $day + 14, $year);
        case "1m":
            return mktime(0, 0, 0, $month + 1, $day, $year);
        case "3m";
            return mktime(0, 0, 0, $month + 3, $day, $year);
        case "1y";
            return mktime(0, 0, 0, $month, $day, $year + 1);
        case "1w":
        default:
            return mktime(0, 0, 0, $month, $day + 7, $year);
        }
    }
}

?>
